============
logging.conf
============

You can specify a special logging configuration file in the ``keystone.conf``
configuration file. For example, ``/etc/keystone/logging.conf``.

For details, see the `Python logging module documentation
<https://docs.python.org/2/howto/logging.html#configuring-logging>`__.

.. literalinclude:: ../../../../etc/logging.conf.sample
